import type { RouteRecordRaw } from 'vue-router'
import { Layout } from '@/router/constant'

/**
 * @param name 路由名称, 必须设置,且不能重名
 * @param meta 路由元信息（路由附带扩展信息）
 * @param redirect 重定向地址, 访问这个路由时,自定进行重定向
 * @param meta.disabled 禁用整个菜单
 * @param meta.title 菜单名称
 * @param meta.icon 菜单图标
 * @param meta.keepAlive 缓存该路由
 * @param meta.sort 排序越小越排前
 *
 */
const routes: Array<RouteRecordRaw> = [
  {
    path: '/',
    name: 'final',
    redirect: '/final',
    component: Layout,
    meta: {
      title: '任务终审',
      permissions: ['final-main'],
      svgname: 'final',
      svgsize: 22,
      sort: 4,
    },
    children: [
      {
        path: 'final',
        name: 'final-main',
        meta: {
          title: '任务终审',
        },
        component: () => import('@/views/final/index.vue'),
      },
      {
        path: 'final-detail',
        name: 'final-detail',
        meta: {
          title: '任务终审详情',
        },
        component: () => import('@/views/task/content/Content.vue'),
      },
    ],
  },
]

export default routes
